SUMMARY = """
ABIL BIJU

AI Engineer focused on Artificial Intelligence,
Machine Learning and Cybersecurity.

Passionate about building intelligent real-world
applications using LLMs, computer vision,
and deep learning.

Portfolio:
https://abilbiju.dev
"""

SKILLS = """
TECHNICAL SKILLS

Python
R
SQL
Machine Learning
Artificial Intelligence
Large Language Models (LLM)

SOFT SKILLS

Problem Solving
Critical Thinking
Leadership
Adaptability
"""

PROJECTS = """
PROJECTS

Live Event Detection using Audio Deep Learning

Real-time Doodle Classifier
(Google QuickDraw dataset)

Intrusion Detection System using Suricata

Research Paper Analysis
using LLM and LangChain

More:
https://abilbiju.dev
"""

EXPERIENCE = """
EXPERIENCE

AI Intern
KeyValue Software Systems
2025

Cybersecurity Intern
CodeAlpha
2024

Data Science Intern
Orbo.ai
2023
"""

CONTACT = """
CONTACT

Email:
abilbiju2004@gmail.com

GitHub:
https://github.com/abilbiju

LinkedIn:
https://linkedin.com/in/abil-biju

Portfolio:
https://abilbiju.dev
"""

RESUME = """
RESUME

Download:
https://abilbiju.dev/resume.pdf

Education:

B.Tech Computer Science (Data Science)
Mar Athanasius College of Engineering

CGPA:
7.99

Expected Graduation:
2026
"""